# xOpera startup examples
This folder contains simple, startup, minimal deployment templates examples that can help users to learn how to use 
xOpera orchestrator. These examples can prove to the user, that the `opera` CLI tool works and that is easy to use.
However, examples here show how basic things are done and not much more. The contents evolve with the new features of 
the opera orchestrator. So, if you wish to explore deeper with more complex xOpera examples go to [xopera-examples] 
repository. A separate repository is there to contain deployment templates for exploring deeper, elaborate use cases, 
such as Docker, Kuberentes and cloud deployments and to show the options that TOSCA and opera open up for the users.

[xopera-examples]: https://github.com/xlab-si/xopera-examples
